.. _rockverse_docs_maillist:

Mailing list
------------

Subscribe to our mailing list to receive
notifications about new releases and tutorials.

.. raw:: html

  <iframe width="450" height="480" src="https://52f75dbc.sibforms.com/serve/MUIFAC2tkhJj8UnKQUqfvI8mcMjO3iZqF__e2VE3r44qFYTCkqNZ1c7-rrKm8oHCMn8v73xApnLWsl1RkLOvss7u0Qf5iorC8LS9f3Je6ZF_VosNdxwHSv4FE32oKv2CwUvr5I5KjXuHIwWKDXMOZoCRhorlTz4YlvUe4ThEbRb3SjlNT6Croa_sWG6AL3fHUR28ppzflI8z6lRT" frameborder="0" scrolling="auto" allowfullscreen style="display: block;margin-left: auto;margin-right: auto;max-width: 100%;"></iframe>
